@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 # PODNAME: tapper_reports_web_cgi.pl
 # ABSTRACT: Tapper - web gui start script - cgi
 
@@ -25,19 +25,6 @@ See L<Catalyst::Manual>
 
 Run a Catalyst application as a cgi script.
 
-=head1 NAME
-
-tapper_reports_web_cgi.pl - Catalyst CGI
-
-=head1 AUTHORS
-
-Catalyst Contributors, see Catalyst.pm
-
-=head1 COPYRIGHT
-
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 AUTHORS
 
 =over 4
@@ -54,7 +41,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
