@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 # PODNAME: tapper_reports_web_fastcgi.pl
 # ABSTRACT: Tapper - web gui start script - fastcgi
 
@@ -40,25 +40,12 @@ tapper_reports_web_fastcgi.pl [options]
                  to the webserver
    --proc_title  Set the process title (if possible)
 
-=head1 DESCRIPTION
-
-Run a Catalyst application as fastcgi.
-
 =head1 NAME
 
 tapper_reports_web_fastcgi.pl - Catalyst FastCGI
 
 =head1 AUTHORS
 
-Catalyst Contributors, see Catalyst.pm
-
-=head1 COPYRIGHT
-
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHORS
-
 =over 4
 
 =item *
@@ -73,7 +60,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
