@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 # PODNAME: tapper_reports_web_test.pl
 # ABSTRACT: Tapper - web gui test
 
@@ -36,19 +36,6 @@ tapper_reports_web_test.pl [options] uri
 
 Run a Catalyst action from the command line.
 
-=head1 NAME
-
-tapper_reports_web_test.pl - Catalyst Test
-
-=head1 AUTHORS
-
-Catalyst Contributors, see Catalyst.pm
-
-=head1 COPYRIGHT
-
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 AUTHORS
 
 =over 4
@@ -65,7 +52,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
